@@ -20,13 +20,13 @@ class VaultApplet : public Plasma::Applet
 
 public:
     explicit VaultApplet(QObject *parent, const QVariantList &args);
-    ~VaultApplet();
+    ~VaultApplet() override;
 
     QObject *vaultsModel();
 
 private:
     // Applet will be the parent of this object
-    QObject *m_vaultsModel;
+    QObject *m_vaultsModel = nullptr;
 };
 
 #endif // include guard
